<?php

/**
 * @file
 * The Maps Import Cache system is used to ensure that there is only one
 * instance of a given object.
 * It also takes care of caching collection of object or data inside the
 * database cache tables.
 */

namespace Drupal\maps_import\Cache;

/**
 * Maps Import Cache class interface.
 */
interface CacheInterface {

  /**
   * Get the current cache instance.
   *
   * @return CacheInterface
   */
  public static function getInstance();

  /**
   * Load all records from database.
   *
   * @return array
   *   The fetched data if any.
   */
  public function loadAll();

  /**
   * Get a single data from database.
   *
   * @param mixed $criterium
   *   The value used to filter the data.
   * @param string $column
   *   The column where to search for the given criteria. If NULL, the default
   *   column defined by child class is used.
   * @param array $conditions
   *   See the method load() below.
   *
   * @return mixed
   *   An instance of the requested data or FALSE if no data was found.
   */
  public function loadSingle($criterium, $column = NULL, array $conditions = array());

  /**
   * Get a set of objects from database.
   *
   * @param mixed $critera
   *   An array of values to filter by.
   * @param string $column
   *   The column where to search for the given criteria. If NULL,
   *   the default column defined by child class is used.
   * @param array $conditions
   *   An array of conditions to filter the results with.
   *
   * @return array
   *   A list of the retrieved data if any.
   */
  public function load(array $criteria, $column = NULL, array $conditions = array());

  /**
   * Clear the cached data if wrapper supports caching.
   */
  public function clearBinCache();

}
